==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/RFQTOTALS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RFQTOTALS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RFQTOTALS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICELINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERCOUNT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQTOTALS_Type", propOrder = {
    "partlinecount",
    "servicelinecount",
    "rfqlinecount",
    "suppliercount"
})
public class RFQTOTALS_Type {

    @XmlElement(name = "PARTLINECOUNT")
    protected Long partlinecount;
    @XmlElement(name = "SERVICELINECOUNT")
    protected Long servicelinecount;
    @XmlElement(name = "RFQLINECOUNT")
    protected Long rfqlinecount;
    @XmlElement(name = "SUPPLIERCOUNT")
    protected Long suppliercount;

    /**
     * Gets the value of the partlinecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPARTLINECOUNT() {
        return partlinecount;
    }

    /**
     * Sets the value of the partlinecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPARTLINECOUNT(Long value) {
        this.partlinecount = value;
    }

    /**
     * Gets the value of the servicelinecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSERVICELINECOUNT() {
        return servicelinecount;
    }

    /**
     * Sets the value of the servicelinecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSERVICELINECOUNT(Long value) {
        this.servicelinecount = value;
    }

    /**
     * Gets the value of the rfqlinecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRFQLINECOUNT() {
        return rfqlinecount;
    }

    /**
     * Sets the value of the rfqlinecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRFQLINECOUNT(Long value) {
        this.rfqlinecount = value;
    }

    /**
     * Gets the value of the suppliercount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSUPPLIERCOUNT() {
        return suppliercount;
    }

    /**
     * Sets the value of the suppliercount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSUPPLIERCOUNT(Long value) {
        this.suppliercount = value;
    }

}

==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/RFQTOTALS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RFQTOTALS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RFQTOTALS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICELINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERCOUNT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQTOTALS_Type", propOrder = {
    "partlinecount",
    "servicelinecount",
    "rfqlinecount",
    "suppliercount"
})
public class RFQTOTALS_Type {

    @XmlElement(name = "PARTLINECOUNT")
    protected Long partlinecount;
    @XmlElement(name = "SERVICELINECOUNT")
    protected Long servicelinecount;
    @XmlElement(name = "RFQLINECOUNT")
    protected Long rfqlinecount;
    @XmlElement(name = "SUPPLIERCOUNT")
    protected Long suppliercount;

    /**
     * Obtient la valeur de la propriété partlinecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPARTLINECOUNT() {
        return partlinecount;
    }

    /**
     * Définit la valeur de la propriété partlinecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPARTLINECOUNT(Long value) {
        this.partlinecount = value;
    }

    /**
     * Obtient la valeur de la propriété servicelinecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSERVICELINECOUNT() {
        return servicelinecount;
    }

    /**
     * Définit la valeur de la propriété servicelinecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSERVICELINECOUNT(Long value) {
        this.servicelinecount = value;
    }

    /**
     * Obtient la valeur de la propriété rfqlinecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRFQLINECOUNT() {
        return rfqlinecount;
    }

    /**
     * Définit la valeur de la propriété rfqlinecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRFQLINECOUNT(Long value) {
        this.rfqlinecount = value;
    }

    /**
     * Obtient la valeur de la propriété suppliercount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSUPPLIERCOUNT() {
        return suppliercount;
    }

    /**
     * Définit la valeur de la propriété suppliercount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSUPPLIERCOUNT(Long value) {
        this.suppliercount = value;
    }

}
